########################################################################
#
#       License: BSD
#       Created: August 5, 2010
#       Author:  Francesc Alted - francesc@blosc.org
#
########################################################################

"""
Unit tests for bcolz
====================

This package contains some modules which provide a ``suite()``
function (with no arguments) which returns a test suite for some
bcolz functionality.
"""

from bcolz.tests.all import test, suite  # noqa
